Index: src/arm/macro-assembler-arm.h |
diff --git a/src/arm/macro-assembler-arm.h b/src/arm/macro-assembler-arm.h |
index 8ab676f39b2a91d13c6567da46fc7370810b952c..5c6ba0aba5493be73d49bef277b9a5360aba4622 100644 |
--- a/src/arm/macro-assembler-arm.h |
+++ b/src/arm/macro-assembler-arm.h |
@@ -763,12 +763,8 @@ class MacroAssembler: public Assembler { |
Label* gc_required, |
AllocationFlags flags); |
- void Allocate(Register object_size, |
- Register result, |
- Register scratch1, |
- Register scratch2, |
- Label* gc_required, |
- AllocationFlags flags); |
+ void Allocate(Register object_size, Register result, Register result_end, |
+ Register scratch, Label* gc_required, AllocationFlags flags); |
void AllocateTwoByteString(Register result, |
Register length, |
@@ -827,12 +823,11 @@ class MacroAssembler: public Assembler { |
Register length, |
Register scratch); |
- // Initialize fields with filler values. Fields starting at |start_offset| |
- // not including end_offset are overwritten with the value in |filler|. At |
- // the end the loop, |start_offset| takes the value of |end_offset|. |
- void InitializeFieldsWithFiller(Register start_offset, |
- Register end_offset, |
- Register filler); |
+ // Initialize fields with filler values. Fields starting at |current_address| |
+ // not including |end_address| are overwritten with the value in |filler|. At |
+ // the end the loop, |current_address| takes the value of |end_address|. |
+ void InitializeFieldsWithFiller(Register current_address, |
+ Register end_address, Register filler); |
// --------------------------------------------------------------------------- |
// Support functions. |